// This file is part of Substrate.

// Copyright (C) 2022 Parity Technologies (UK) Ltd.
// SPDX-License-Identifier: Apache-2.0

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

//! Autogenerated weights for pallet_file_bank
//!
//! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
//! DATE: 2022-09-27, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
//! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("cess-staking-testnet"), DB CACHE: 1024

// Executed Command:
// ./target/release/cess-node
// benchmark
// --chain
// cess-staking-testnet
// --execution=wasm
// --wasm-execution=compiled
// --pallet
// pallet_file_bank
// --extrinsic
// *
// --steps
// 50
// --repeat
// 20
// --template=./.maintain/frame-weight-template.hbs
// --output=./c-pallets/file-bank/src/weights

#![cfg_attr(rustfmt, rustfmt_skip)]
#![allow(unused_parens)]
#![allow(unused_imports)]

use frame_support::{traits::Get, weights::{Weight, constants::RocksDbWeight}};
use sp_std::marker::PhantomData;

/// Weight functions needed for pallet_file_bank.
pub trait WeightInfo {
	fn upload_filler(v: u32, ) -> Weight;
	fn buy_package() -> Weight;
	fn upgrade_package() -> Weight;
	fn renewal_package() -> Weight;
	fn upload_declaration() -> Weight;
	fn upload(v: u32, ) -> Weight;
	fn delete_file() -> Weight;
	fn recover_file() -> Weight;
	fn clear_invalid_file() -> Weight;
}

/// Weights for pallet_file_bank using the Substrate node and recommended hardware.
pub struct SubstrateWeight<T>(PhantomData<T>);
impl<T: frame_system::Config> WeightInfo for SubstrateWeight<T> {
	// Storage: FileMap SchedulerMap (r:1 w:0)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: FileBank FillerIndexCount (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:1)
	// Storage: FileBank FillerMap (r:1 w:1)
	// Storage: FileBank FillerKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFillerKeysMap (r:1 w:1)
	// Storage: SchedulerCredit CurrentCounters (r:1 w:1)
	fn upload_filler(v: u32, ) -> Weight {
		(64_554_000 as Weight)
			// Standard Error: 173_000
			.saturating_add((16_287_000 as Weight).saturating_mul(v as Weight))
			.saturating_add(T::DbWeight::get().reads(5 as Weight))
			.saturating_add(T::DbWeight::get().reads((2 as Weight).saturating_mul(v as Weight)))
			.saturating_add(T::DbWeight::get().writes(4 as Weight))
			.saturating_add(T::DbWeight::get().writes((2 as Weight).saturating_mul(v as Weight)))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: Sminer PurchasedSpace (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:0)
	// Storage: Sminer TotalIdleSpace (r:1 w:0)
	fn buy_package() -> Weight {
		(152_102_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(4 as Weight))
			.saturating_add(T::DbWeight::get().writes(2 as Weight))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: Sminer PurchasedSpace (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:0)
	// Storage: Sminer TotalServiceSpace (r:1 w:0)
	// Storage: System Account (r:1 w:1)
	fn upgrade_package() -> Weight {
		(1_090_602_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(5 as Weight))
			.saturating_add(T::DbWeight::get().writes(3 as Weight))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	fn renewal_package() -> Weight {
		(156_300_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank FileIndexCount (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	fn upload_declaration() -> Weight {
		(51_099_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(4 as Weight))
			.saturating_add(T::DbWeight::get().writes(4 as Weight))
	}
	// Storage: FileMap SchedulerMap (r:1 w:0)
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank UserHoldFileList (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: SchedulerCredit CurrentCounters (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: FileBank FillerMap (r:3 w:1)
	// Storage: FileBank FillerKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFillerKeysMap (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:1)
	fn upload(v: u32, ) -> Weight {
		(0 as Weight)
			// Standard Error: 1_434_000
			.saturating_add((174_499_000 as Weight).saturating_mul(v as Weight))
			.saturating_add(T::DbWeight::get().reads(12 as Weight))
			.saturating_add(T::DbWeight::get().reads((2 as Weight).saturating_mul(v as Weight)))
			.saturating_add(T::DbWeight::get().writes(9 as Weight))
			.saturating_add(T::DbWeight::get().writes((2 as Weight).saturating_mul(v as Weight)))
	}
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	// Storage: FileBank UserHoldFileList (r:1 w:1)
	fn delete_file() -> Weight {
		(260_398_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(8 as Weight))
			.saturating_add(T::DbWeight::get().writes(8 as Weight))
	}
	// Storage: FileBank FileRecovery (r:1 w:1)
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	fn recover_file() -> Weight {
		(320_666_000 as Weight)
			// Standard Error: 109_000
			.saturating_add(147_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(5 as Weight))
			.saturating_add(T::DbWeight::get().writes(5 as Weight))
	}
	// Storage: FileBank InvalidFile (r:1 w:1)
	fn clear_invalid_file() -> Weight {
		(39_300_000 as Weight)
			.saturating_add(T::DbWeight::get().reads(1 as Weight))
			.saturating_add(T::DbWeight::get().writes(1 as Weight))
	}
}

// For backwards compatibility and tests
impl WeightInfo for () {
	// Storage: FileMap SchedulerMap (r:1 w:0)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: FileBank FillerIndexCount (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:1)
	// Storage: FileBank FillerMap (r:1 w:1)
	// Storage: FileBank FillerKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFillerKeysMap (r:1 w:1)
	// Storage: SchedulerCredit CurrentCounters (r:1 w:1)
	fn upload_filler(v: u32, ) -> Weight {
		(64_554_000 as Weight)
			// Standard Error: 173_000
			.saturating_add((16_287_000 as Weight).saturating_mul(v as Weight))
			.saturating_add(RocksDbWeight::get().reads(5 as Weight))
			.saturating_add(RocksDbWeight::get().reads((2 as Weight).saturating_mul(v as Weight)))
			.saturating_add(RocksDbWeight::get().writes(4 as Weight))
			.saturating_add(RocksDbWeight::get().writes((2 as Weight).saturating_mul(v as Weight)))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: Sminer PurchasedSpace (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:0)
	// Storage: Sminer TotalIdleSpace (r:1 w:0)
	fn buy_package() -> Weight {
		(152_102_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(4 as Weight))
			.saturating_add(RocksDbWeight::get().writes(2 as Weight))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: Sminer PurchasedSpace (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:0)
	// Storage: Sminer TotalServiceSpace (r:1 w:0)
	// Storage: System Account (r:1 w:1)
	fn upgrade_package() -> Weight {
		(1_090_602_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(5 as Weight))
			.saturating_add(RocksDbWeight::get().writes(3 as Weight))
	}
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	fn renewal_package() -> Weight {
		(156_300_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank FileIndexCount (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	fn upload_declaration() -> Weight {
		(51_099_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(4 as Weight))
			.saturating_add(RocksDbWeight::get().writes(4 as Weight))
	}
	// Storage: FileMap SchedulerMap (r:1 w:0)
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank UserHoldFileList (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: SchedulerCredit CurrentCounters (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: FileBank FillerMap (r:3 w:1)
	// Storage: FileBank FillerKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFillerKeysMap (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: Sminer TotalIdleSpace (r:1 w:1)
	fn upload(v: u32, ) -> Weight {
		(0 as Weight)
			// Standard Error: 1_434_000
			.saturating_add((174_499_000 as Weight).saturating_mul(v as Weight))
			.saturating_add(RocksDbWeight::get().reads(12 as Weight))
			.saturating_add(RocksDbWeight::get().reads((2 as Weight).saturating_mul(v as Weight)))
			.saturating_add(RocksDbWeight::get().writes(9 as Weight))
			.saturating_add(RocksDbWeight::get().writes((2 as Weight).saturating_mul(v as Weight)))
	}
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	// Storage: FileBank UserHoldFileList (r:1 w:1)
	fn delete_file() -> Weight {
		(260_398_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(8 as Weight))
			.saturating_add(RocksDbWeight::get().writes(8 as Weight))
	}
	// Storage: FileBank FileRecovery (r:1 w:1)
	// Storage: FileBank File (r:1 w:1)
	// Storage: FileBank PurchasedPackage (r:1 w:1)
	// Storage: FileBank InvalidFile (r:1 w:1)
	// Storage: Sminer MinerItems (r:1 w:1)
	// Storage: Sminer TotalServiceSpace (r:1 w:1)
	// Storage: FileBank FileKeysMap (r:1 w:1)
	// Storage: FileBank CounterForFileKeysMap (r:1 w:1)
	fn recover_file() -> Weight {
		(320_666_000 as Weight)
			// Standard Error: 109_000
			.saturating_add(147_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(5 as Weight))
			.saturating_add(RocksDbWeight::get().writes(5 as Weight))
	}
	// Storage: FileBank InvalidFile (r:1 w:1)
	fn clear_invalid_file() -> Weight {
		(39_300_000 as Weight)
			.saturating_add(RocksDbWeight::get().reads(1 as Weight))
			.saturating_add(RocksDbWeight::get().writes(1 as Weight))
	}
}
